@@ -8,7 +8,6 @@ from gene import NAMESPACE_LOOKUP, PREFIX_LOOKUP, ITEM_TYPES
 from gene.database import Database
 from gene.schemas import Gene, SourceMeta, MatchType, SourceName, \
     ServiceMeta, SourcePriority, NormalizeService, SearchService
-from ga4gh.vrsatile.pydantic.vrs_model import Gene as GeneValueObject
 from ga4gh.vrsatile.pydantic.vrsatile_model import GeneDescriptor, Extension
 from botocore.exceptions import ClientError
 from boto3.dynamodb.conditions import Key
@@ -39,7 +38,8 @@ class QueryHandler:
         """
         self.db = Database(db_url=db_url, region_name=db_region)
 
-    def emit_warnings(self, query_str: str) -> List:
+    @staticmethod
+    def emit_warnings(query_str: str) -> List:
         """Emit warnings if query contains non breaking space characters.
 
         :param str query_str: query string
@@ -114,7 +114,7 @@ class QueryHandler:
         elif matches[src_name]['match_type'].value == match_type.value:
             matches[src_name]['records'].append(gene)
 
-        return (response, src_name)
+        return response, src_name
 
     def fetch_records(self,
                       response: Dict[str, Dict],
@@ -144,7 +144,7 @@ class QueryHandler:
             except ClientError as e:
                 logger.error(e.response['Error']['Message'])
 
-        return (response, matched_sources)
+        return response, matched_sources
 
     def fill_no_matches(self, resp: Dict) -> Dict:
         """Fill all empty source_matches slots with NO_MATCH results.
@@ -193,7 +193,7 @@ class QueryHandler:
                 result = self.db.genes.query(
                     KeyConditionExpression=filter_exp
                 )
-                if len(result['Items']) > 0:  # TODO remove check?
+                if len(result['Items']) > 0:
                     concept_id_items += result['Items']
             except ClientError as e:
                 logger.error(e.response['Error']['Message'])
@@ -202,7 +202,7 @@ class QueryHandler:
             (resp, src_name) = self.add_record(resp, item,
                                                MatchType.CONCEPT_ID)
             sources = sources - {src_name}
-        return (resp, sources)
+        return resp, sources
 
     def check_match_type(self,
                          query: str,
@@ -231,14 +231,14 @@ class QueryHandler:
                 sources = sources - matched_srcs
         except ClientError as e:
             logger.error(e.response['Error']['Message'])
-        return (resp, sources)
+        return resp, sources
 
-    def response_keyed(self, query: str, sources: List[str]) -> Dict:
+    def response_keyed(self, query: str, sources: Set[str]) -> Dict:
         """Return response as dict where key is source name and value
         is a list of records. Corresponds to `keyed=true` API parameter.
 
         :param str query: string to match against
-        :param List[str] sources: sources to match from
+        :param Set[str] sources: sources to match from
         :return: completed response object to return to client
         """
         resp = {
@@ -269,7 +269,7 @@ class QueryHandler:
 
         return resp
 
-    def response_list(self, query: str, sources: List[str]) -> Dict:
+    def response_list(self, query: str, sources: Set[str]) -> Dict:
         """Return response as list, where the first key-value in each item
         is the source name. Corresponds to `keyed=false` API parameter.
 
@@ -291,7 +291,8 @@ class QueryHandler:
 
         return response_dict
 
-    def _get_service_meta(self) -> ServiceMeta:
+    @staticmethod
+    def _get_service_meta() -> ServiceMeta:
         """Return metadata about gene-normalizer service.
 
         :return: Service Meta
@@ -302,7 +303,7 @@ class QueryHandler:
         )
 
     def search(self, query_str: str, keyed: bool = False,
-               incl: str = '', excl: str = '', **params):
+               incl: str = '', excl: str = '', **params) -> SearchService:
         """Return highest match for each source.
 
         :param str query_str: query, a string, to search for
@@ -316,7 +317,7 @@ class QueryHandler:
             exclude. Will include all other source. Case-insensitive. Raises
             InvalidParameterException if both incl and excl args are
             provided, or if invalid source names are given.
-        :return: dict containing all matches found in sources.
+        :return: SearchService class containing all matches found in sources.
         """
         possible_sources = {name.value.lower(): name.value for name in
                             SourceName.__members__.values()}
@@ -365,8 +366,7 @@ class QueryHandler:
             resp = self.response_list(query_str, query_sources)
 
         resp['service_meta_'] = self._get_service_meta()
-        assert SearchService(**resp)
-        return resp
+        return SearchService(**resp)
 
     def _add_merged_meta(self, response: Dict) -> Dict:
         """Add source metadata to response object.
@@ -376,7 +376,7 @@ class QueryHandler:
         """
         sources_meta = {}
         gene_descr = response['gene_descriptor']
-        ids = [gene_descr['gene']['gene_id']] + gene_descr.get('xrefs', [])
+        ids = [gene_descr['gene_id']] + gene_descr.get('xrefs', [])
         for concept_id in ids:
             prefix = concept_id.split(':')[0]
             src_name = PREFIX_LOOKUP[prefix.lower()]
@@ -386,7 +386,7 @@ class QueryHandler:
         return response
 
     def add_gene_descriptor(self, response, record, match_type,
-                            possible_concepts=[]):
+                            possible_concepts=[]) -> Dict:
         """Add gene descriptor to response.
 
         :param Dict response: Response object
@@ -399,7 +399,7 @@ class QueryHandler:
         params = {
             "id": f"normalize.gene:{quote(response['query'])}",
             "label": record["symbol"],
-            "gene": GeneValueObject(gene_id=record["concept_id"])
+            "gene_id": record["concept_id"]
         }
 
         # xrefs
@@ -460,7 +460,8 @@ class QueryHandler:
         response["match_type"] = match_type
         return response
 
-    def _record_order(self, record: Dict) -> (int, str):
+    @staticmethod
+    def _record_order(record: Dict) -> (int, str):
         """Construct priority order for matching. Only called by sort().
 
         :param Dict record: individual record item in iterable to sort
@@ -470,7 +471,8 @@ class QueryHandler:
         source_rank = SourcePriority[src]
         return source_rank, record['concept_id']
 
-    def _handle_failed_merge_ref(self, record, response, query) -> Dict:
+    @staticmethod
+    def _handle_failed_merge_ref(record, response, query) -> Dict:
         """Log + fill out response for a failed merge reference lookup.
 
         :param Dict record: record containing failed merge_ref
@@ -483,7 +485,7 @@ class QueryHandler:
         response['match_type'] = MatchType.NO_MATCH
         return response
 
-    def normalize(self, query: str) -> Dict:
+    def normalize(self, query: str) -> NormalizeService:
         """Return normalized concept for query.
 
         :param str query: String to find normalized concept for
@@ -497,32 +499,36 @@ class QueryHandler:
 
         if query == '':
             response['match_type'] = MatchType.NO_MATCH
-            return response
+            return NormalizeService(**response)
         query_str = query.lower().strip()
 
         # check merged concept ID match
         record = self.db.get_record_by_id(query_str, case_sensitive=False,
                                           merge=True)
         if record:
-            return self.add_gene_descriptor(response, record,
-                                            MatchType.CONCEPT_ID)
+            response = self.add_gene_descriptor(
+                response, record, MatchType.CONCEPT_ID)
+            return NormalizeService(**response)
 
         # check concept ID match
         record = self.db.get_record_by_id(query_str, case_sensitive=False)
         if record:
             merge_ref = record.get('merge_ref')
             if not merge_ref:
-                return self.add_gene_descriptor(response, record,
-                                                MatchType.CONCEPT_ID)
+                response = self.add_gene_descriptor(
+                    response, record, MatchType.CONCEPT_ID)
+                return NormalizeService(**response)
             merge = self.db.get_record_by_id(merge_ref,
                                              case_sensitive=False,
                                              merge=True)
             if merge is None:
-                return self._handle_failed_merge_ref(record, response,
-                                                     query_str)
+                response = self._handle_failed_merge_ref(
+                    record, response, query_str)
+                return NormalizeService(**response)
             else:
-                return self.add_gene_descriptor(response, merge,
-                                                MatchType.CONCEPT_ID)
+                response = self.add_gene_descriptor(
+                    response, merge, MatchType.CONCEPT_ID)
+                return NormalizeService(**response)
 
         # check other match types
         matching_records = None
@@ -546,25 +552,27 @@ class QueryHandler:
                 if record:
                     merge_ref = record.get('merge_ref')
                     if not merge_ref:
-                        return self.add_gene_descriptor(
+                        response = self.add_gene_descriptor(
                             response, record,
                             MatchType[match_type.upper()],
                             possible_concepts
                         )
+                        return NormalizeService(**response)
                     merge = self.db.get_record_by_id(record['merge_ref'],
                                                      case_sensitive=False,
                                                      merge=True)
                     if merge is None:
-                        return self._handle_failed_merge_ref(record, response,
-                                                             query_str)
+                        response = self._handle_failed_merge_ref(
+                            record, response, query_str)
+                        return NormalizeService(**response)
                     else:
-                        return self.add_gene_descriptor(
+                        response = self.add_gene_descriptor(
                             response, merge,
                             MatchType[match_type.upper()],
                             possible_concepts
                         )
+                        return NormalizeService(**response)
 
         if not matching_records:
             response['match_type'] = MatchType.NO_MATCH
-        assert NormalizeService(**response)
-        return response
+        return NormalizeService(**response)
